CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
41 lines
946 B
C++
41 lines
946 B
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
HIP_TEST_CASE(Stress_hipMalloc) {
|
|
int* d_a = nullptr;
|
|
SECTION("Size 10") {
|
|
auto res = hipMalloc(&d_a, sizeof(10));
|
|
REQUIRE(res == hipSuccess);
|
|
HIP_CHECK(hipFree(d_a));
|
|
d_a = nullptr;
|
|
}
|
|
SECTION("Size 100") {
|
|
auto res = hipMalloc(&d_a, sizeof(100));
|
|
REQUIRE(res == hipSuccess);
|
|
HIP_CHECK(hipFree(d_a));
|
|
d_a = nullptr;
|
|
}
|
|
SECTION("Size 1000") {
|
|
auto res = hipMalloc(&d_a, sizeof(1000));
|
|
REQUIRE(res == hipSuccess);
|
|
HIP_CHECK(hipFree(d_a));
|
|
d_a = nullptr;
|
|
}
|
|
SECTION("Size 10000") {
|
|
auto res = hipMalloc(&d_a, sizeof(10000));
|
|
REQUIRE(res == hipSuccess);
|
|
HIP_CHECK(hipFree(d_a));
|
|
d_a = nullptr;
|
|
}
|
|
SECTION("Size MAX") {
|
|
auto res = hipMalloc(&d_a, ~(size_t)0);
|
|
REQUIRE(res == hipErrorOutOfMemory);
|
|
d_a = nullptr;
|
|
}
|
|
}
|